@@ -8,7 +8,7 @@ use Moo;
 
 with 'Catmandu::Logger';
 
-our $VERSION = "0.02152";
+our $VERSION = "0.02153";
 
 has parser  => (is => 'ro', lazy => 1, builder => '_build_parser');
 has mapping => (is => 'ro');
@@ -111,7 +111,7 @@ sub visit {
 
                     $qualifier = $op->{field};
 
-                } elsif ($mapping->{field}) {
+                } elsif ($q_mapping->{field}) {
 
                     $qualifier = $q_mapping->{field};
 
